@@ -1,8 +1,8 @@
 from typing import List
 
-from bleak.backends.bluezdbus.utils import extract_service_handle_from_path
-from bleak.backends.service import BleakGATTService
-from bleak.backends.bluezdbus.characteristic import BleakGATTCharacteristicBlueZDBus
+from ..service import BleakGATTService
+from .characteristic import BleakGATTCharacteristicBlueZDBus
+from .utils import extract_service_handle_from_path
 
 
 class BleakGATTServiceBlueZDBus(BleakGATTService):
@@ -20,7 +20,7 @@ class BleakGATTServiceBlueZDBus(BleakGATTService):
         return self.obj["UUID"]
 
     @property
-    def handle(self) -> str:
+    def handle(self) -> int:
         """The integer handle of this service"""
         return self.__handle
 
