@@ -7,11 +7,11 @@ Created on 2019-03-19 by hbldh <henrik.blidh@nedomkull.com>
 """
 import abc
 import enum
+from typing import Any, List, Union
 from uuid import UUID
-from typing import List, Union, Any
 
-from bleak.backends.descriptor import BleakGATTDescriptor
-from bleak.uuids import uuidstr_to_str
+from ..uuids import uuidstr_to_str
+from .descriptor import BleakGATTDescriptor
 
 
 class GattCharacteristicsFlags(enum.Enum):
@@ -30,8 +30,17 @@ class GattCharacteristicsFlags(enum.Enum):
 class BleakGATTCharacteristic(abc.ABC):
     """Interface for the Bleak representation of a GATT Characteristic"""
 
-    def __init__(self, obj: Any):
+    def __init__(self, obj: Any, max_write_without_response_size: int):
+        """
+        Args:
+            obj:
+                A platform-specific object for this characteristic.
+            max_write_without_response_size:
+                The maximum size in bytes that can be written to the
+                characteristic in a single write without response command.
+        """
         self.obj = obj
+        self._max_write_without_response_size = max_write_without_response_size
 
     def __str__(self):
         return f"{self.uuid} (Handle: {self.handle}): {self.description}"
@@ -71,9 +80,22 @@ class BleakGATTCharacteristic(abc.ABC):
         """Properties of this characteristic"""
         raise NotImplementedError()
 
+    @property
+    def max_write_without_response_size(self) -> int:
+        """
+        Gets the maximum size in bytes that can be used for the *data* argument
+        of :meth:`BleakClient.write_gatt_char()` when ``response=False``.
+
+        .. warning:: Linux quirk: For BlueZ versions < 5.62, this property
+            will always return ``20``.
+
+        .. versionadded:: 0.16.0
+        """
+        return self._max_write_without_response_size
+
     @property
     @abc.abstractmethod
-    def descriptors(self) -> List:
+    def descriptors(self) -> List[BleakGATTDescriptor]:
         """List of descriptors for this service"""
         raise NotImplementedError()
 
