@@ -7,13 +7,18 @@ Created on 2018-04-23 by hbldh <henrik.blidh@nedomkull.com>
 """
 import abc
 import asyncio
+import os
+import platform
 import uuid
-from typing import Callable, Optional, Union
+from typing import Callable, Optional, Type, Union
 from warnings import warn
 
-from bleak.backends.service import BleakGATTServiceCollection
-from bleak.backends.characteristic import BleakGATTCharacteristic
-from bleak.backends.device import BLEDevice
+from ..exc import BleakError
+from .service import BleakGATTServiceCollection
+from .characteristic import BleakGATTCharacteristic
+from .device import BLEDevice
+
+NotifyCallback = Callable[[bytearray], None]
 
 
 class BaseBleakClient(abc.ABC):
@@ -37,53 +42,29 @@ class BaseBleakClient(abc.ABC):
         else:
             self.address = address_or_ble_device
 
-        self.services = BleakGATTServiceCollection()
-
-        self._services_resolved = False
-        self._notification_callbacks = {}
+        self.services: Optional[BleakGATTServiceCollection] = None
 
         self._timeout = kwargs.get("timeout", 10.0)
-        self._disconnected_callback = kwargs.get("disconnected_callback")
-
-    def __str__(self):
-        return "{0}, {1}".format(self.__class__.__name__, self.address)
-
-    def __repr__(self):
-        return "<{0}, {1}, {2}>".format(
-            self.__class__.__name__,
-            self.address,
-            super(BaseBleakClient, self).__repr__(),
+        self._disconnected_callback: Optional[Callable[[], None]] = kwargs.get(
+            "disconnected_callback"
         )
 
-    # Async Context managers
-
-    async def __aenter__(self):
-        await self.connect()
-        return self
-
-    async def __aexit__(self, exc_type, exc_val, exc_tb):
-        await self.disconnect()
+    @property
+    @abc.abstractmethod
+    def mtu_size(self) -> int:
+        """Gets the negotiated MTU."""
+        raise NotImplementedError
 
     # Connectivity methods
 
     def set_disconnected_callback(
-        self, callback: Optional[Callable[["BaseBleakClient"], None]], **kwargs
+        self, callback: Optional[Callable[[], None]], **kwargs
     ) -> None:
         """Set the disconnect callback.
         The callback will only be called on unsolicited disconnect event.
 
-        Callbacks must accept one input which is the client object itself.
-
         Set the callback to ``None`` to remove any existing callback.
 
-        .. code-block:: python
-
-            def callback(client):
-                print("Client with address {} got disconnected!".format(client.address))
-
-            client.set_disconnected_callback(callback)
-            client.connect()
-
         Args:
             callback: callback to be called on disconnection.
 
@@ -120,7 +101,8 @@ class BaseBleakClient(abc.ABC):
         """Unpair with the peripheral."""
         raise NotImplementedError()
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def is_connected(self) -> bool:
         """Check connection status between this client and the server.
 
@@ -170,7 +152,7 @@ class BaseBleakClient(abc.ABC):
     async def read_gatt_char(
         self,
         char_specifier: Union[BleakGATTCharacteristic, int, str, uuid.UUID],
-        **kwargs
+        **kwargs,
     ) -> bytearray:
         """Perform read operation on the specified GATT characteristic.
 
@@ -233,27 +215,18 @@ class BaseBleakClient(abc.ABC):
     @abc.abstractmethod
     async def start_notify(
         self,
-        char_specifier: Union[BleakGATTCharacteristic, int, str, uuid.UUID],
-        callback: Callable[[int, bytearray], None],
-        **kwargs
+        characteristic: BleakGATTCharacteristic,
+        callback: NotifyCallback,
+        **kwargs,
     ) -> None:
-        """Activate notifications/indications on a characteristic.
+        """
+        Activate notifications/indications on a characteristic.
 
-        Callbacks must accept two inputs. The first will be a integer handle of the characteristic generating the
-        data and the second will be a ``bytearray``.
-
-        .. code-block:: python
-
-            def callback(sender: int, data: bytearray):
-                print(f"{sender}: {data}")
-            client.start_notify(char_uuid, callback)
-
-        Args:
-            char_specifier (BleakGATTCharacteristic, int, str or UUID): The characteristic to activate
-                notifications/indications on a characteristic, specified by either integer handle,
-                UUID or directly by the BleakGATTCharacteristic object representing it.
-            callback (function): The function to be called on notification.
+        Implementers should call the OS function to enable notifications or
+        indications on the characteristic.
 
+        To keep things the same cross-platform, notifications should be preferred
+        over indications if possible when a characteristic supports both.
         """
         raise NotImplementedError()
 
@@ -270,3 +243,30 @@ class BaseBleakClient(abc.ABC):
 
         """
         raise NotImplementedError()
+
+
+def get_platform_client_backend_type() -> Type[BaseBleakClient]:
+    """
+    Gets the platform-specific :class:`BaseBleakClient` type.
+    """
+    if os.environ.get("P4A_BOOTSTRAP") is not None:
+        from bleak.backends.p4android.client import BleakClientP4Android
+
+        return BleakClientP4Android
+
+    if platform.system() == "Linux":
+        from bleak.backends.bluezdbus.client import BleakClientBlueZDBus
+
+        return BleakClientBlueZDBus
+
+    if platform.system() == "Darwin":
+        from bleak.backends.corebluetooth.client import BleakClientCoreBluetooth
+
+        return BleakClientCoreBluetooth
+
+    if platform.system() == "Windows":
+        from bleak.backends.winrt.client import BleakClientWinRT
+
+        return BleakClientWinRT
+
+    raise BleakError(f"Unsupported platform: {platform.system()}")
