@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from typing import Dict
+from uuid import UUID
 
 
 uuid16_dict = {
@@ -82,7 +83,10 @@ uuid16_dict = {
     0x1139: "3D Synchronization",
     0x113A: "MPS Profile",
     0x113B: "MPS Service",
-    # 0x113c to 0x11ff undefined */
+    0x113C: "CTN Access Service",
+    0x113D: "CTN Notification Service",
+    0x113E: "CTN Profile",
+    # 0x113f to 0x11ff undefined */
     0x1200: "PnP Information",
     0x1201: "Generic Networking",
     0x1202: "Generic File Transfer",
@@ -141,7 +145,155 @@ uuid16_dict = {
     0x1826: "Fitness Machine",
     0x1827: "Mesh Provisioning",
     0x1828: "Mesh Proxy",
-    # 0x1829 to 0x27ff undefined */
+    0x1829: "Reconnection Configuration",
+    # 0x182a-0x1839 undefined
+    0x183A: "Insulin Delivery",
+    0x183B: "Binary Sensor",
+    0x183C: "Emergency Configuration",
+    # 0x183D undefined
+    0x183E: "Physical Activity Monitor",
+    # 0x183F-0x1842 undefined
+    0x1843: "Audio Input Control",
+    0x1844: "Volume Control",
+    0x1845: "Volume Offset Control",
+    0x1846: "Coordinated Set Identification Service",
+    0x1847: "Device Time",
+    0x1848: "Media Control Service",
+    0x1849: "Generic Media Control Service",
+    0x184A: "Constant Tone Extension",
+    0x184B: "Telephone Bearer Service",
+    0x184C: "Generic Telephone Bearer Service",
+    0x184D: "Microphone Control",
+    0x184E: "Audio Stream Control Service",
+    0x184F: "Broadcast Audio Scan Service",
+    0x1850: "Published Audio Capabilities Service",
+    0x1851: "Basic Audio Announcement Service",
+    0x1852: "Broadcast Audio Announcement Service",
+    # 0x1853 to 0x26ff undefined */
+    # 0x2700.. GATT Units
+    0x2700: "unitless",
+    0x2701: "length (metre)",
+    0x2702: "mass (kilogram)",
+    0x2703: "time (second)",
+    0x2704: "electric current (ampere)",
+    0x2705: "thermodynamic temperature (kelvin)",
+    0x2706: "amount of substance (mole)",
+    0x2707: "luminous intensity (candela)",
+    0x2710: "area (square metres)",
+    0x2711: "volume (cubic metres)",
+    0x2712: "velocity (metres per second)",
+    0x2713: "acceleration (metres per second squared)",
+    0x2714: "wavenumber (reciprocal metre)",
+    0x2715: "density (kilogram per cubic metre)",
+    0x2716: "surface density (kilogram per square metre)",
+    0x2717: "specific volume (cubic metre per kilogram)",
+    0x2718: "current density (ampere per square metre)",
+    0x2719: "magnetic field strength (ampere per metre)",
+    0x271A: "amount concentration (mole per cubic metre)",
+    0x271B: "mass concentration (kilogram per cubic metre)",
+    0x271C: "luminance (candela per square metre)",
+    0x271D: "refractive index",
+    0x271E: "relative permeability",
+    0x2720: "plane angle (radian)",
+    0x2721: "solid angle (steradian)",
+    0x2722: "frequency (hertz)",
+    0x2723: "force (newton)",
+    0x2724: "pressure (pascal)",
+    0x2725: "energy (joule)",
+    0x2726: "power (watt)",
+    0x2727: "electric charge (coulomb)",
+    0x2728: "electric potential difference (volt)",
+    0x2729: "capacitance (farad)",
+    0x272A: "electric resistance (ohm)",
+    0x272B: "electric conductance (siemens)",
+    0x272C: "magnetic flux (weber)",
+    0x272D: "magnetic flux density (tesla)",
+    0x272E: "inductance (henry)",
+    0x272F: "Celsius temperature (degree Celsius)",
+    0x2730: "luminous flux (lumen)",
+    0x2731: "illuminance (lux)",
+    0x2732: "activity referred to a radionuclide (becquerel)",
+    0x2733: "absorbed dose (gray)",
+    0x2734: "dose equivalent (sievert)",
+    0x2735: "catalytic activity (katal)",
+    0x2740: "dynamic viscosity (pascal second)",
+    0x2741: "moment of force (newton metre)",
+    0x2742: "surface tension (newton per metre)",
+    0x2743: "angular velocity (radian per second)",
+    0x2744: "angular acceleration (radian per second squared)",
+    0x2745: "heat flux density (watt per square metre)",
+    0x2746: "heat capacity (joule per kelvin)",
+    0x2747: "specific heat capacity (joule per kilogram kelvin)",
+    0x2748: "specific energy (joule per kilogram)",
+    0x2749: "thermal conductivity (watt per metre kelvin)",
+    0x274A: "energy density (joule per cubic metre)",
+    0x274B: "electric field strength (volt per metre)",
+    0x274C: "electric charge density (coulomb per cubic metre)",
+    0x274D: "surface charge density (coulomb per square metre)",
+    0x274E: "electric flux density (coulomb per square metre)",
+    0x274F: "permittivity (farad per metre)",
+    0x2750: "permeability (henry per metre)",
+    0x2751: "molar energy (joule per mole)",
+    0x2752: "molar entropy (joule per mole kelvin)",
+    0x2753: "exposure (coulomb per kilogram)",
+    0x2754: "absorbed dose rate (gray per second)",
+    0x2755: "radiant intensity (watt per steradian)",
+    0x2756: "radiance (watt per square metre steradian)",
+    0x2757: "catalytic activity concentration (katal per cubic metre)",
+    0x2760: "time (minute)",
+    0x2761: "time (hour)",
+    0x2762: "time (day)",
+    0x2763: "plane angle (degree)",
+    0x2764: "plane angle (minute)",
+    0x2765: "plane angle (second)",
+    0x2766: "area (hectare)",
+    0x2767: "volume (litre)",
+    0x2768: "mass (tonne)",
+    0x2780: "pressure (bar)",
+    0x2781: "pressure (millimetre of mercury)",
+    0x2782: "length (ångström)",
+    0x2783: "length (nautical mile)",
+    0x2784: "area (barn)",
+    0x2785: "velocity (knot)",
+    0x2786: "logarithmic radio quantity (neper)",
+    0x2787: "logarithmic radio quantity (bel)",
+    0x27A0: "length (yard)",
+    0x27A1: "length (parsec)",
+    0x27A2: "length (inch)",
+    0x27A3: "length (foot)",
+    0x27A4: "length (mile)",
+    0x27A5: "pressure (pound-force per square inch)",
+    0x27A6: "velocity (kilometre per hour)",
+    0x27A7: "velocity (mile per hour)",
+    0x27A8: "angular velocity (revolution per minute)",
+    0x27A9: "energy (gram calorie)",
+    0x27AA: "energy (kilogram calorie)",
+    0x27AB: "energy (kilowatt hour)",
+    0x27AC: "thermodynamic temperature (degree Fahrenheit)",
+    0x27AD: "percentage",
+    0x27AE: "per mille",
+    0x27AF: "period (beats per minute)",
+    0x27B0: "electric charge (ampere hours)",
+    0x27B1: "mass density (milligram per decilitre)",
+    0x27B2: "mass density (millimole per litre)",
+    0x27B3: "time (year)",
+    0x27B4: "time (month)",
+    0x27B5: "concentration (count per cubic metre)",
+    0x27B6: "irradiance (watt per square metre)",
+    0x27B7: "milliliter (per kilogram per minute)",
+    0x27B8: "mass (pound)",
+    0x27B9: "metabolic equivalent",
+    0x27BA: "step (per minute)",
+    0x27BC: "stroke (per minute)",
+    0x27BD: "pace (kilometre per minute)",
+    0x27BE: "luminous efficacy (lumen per watt)",
+    0x27BF: "luminous energy (lumen hour)",
+    0x27C0: "luminous exposure (lux hour)",
+    0x27C1: "mass flow (gram per second)",
+    0x27C2: "volume flow (litre per second)",
+    0x27C3: "sound pressure (decible)",
+    0x27C4: "parts per million",
+    0x27C5: "parts per billion",
     0x2800: "Primary Service",
     0x2801: "Secondary Service",
     0x2802: "Include",
@@ -163,7 +315,9 @@ uuid16_dict = {
     0x290C: "Environmental Sensing Measurement",
     0x290D: "Environmental Sensing Trigger Setting",
     0x290E: "Time Trigger Setting",
-    # 0x290f to 0x29ff undefined */
+    0x290F: "Complete BR-EDR Transport Block Data",
+    # 0x2910 to 0x29ff undefined */
+    # 0x2a00.. GATT characteristic and Object Types
     0x2A00: "Device Name",
     0x2A01: "Appearance",
     0x2A02: "Peripheral Privacy Flag",
@@ -180,12 +334,12 @@ uuid16_dict = {
     0x2A0D: "DST Offset",
     0x2A0E: "Time Zone",
     0x2A0F: "Local Time Information",
-    # 0x2a10 undefined */
+    0x2A10: "Secondary Time Zone",
     0x2A11: "Time with DST",
     0x2A12: "Time Accuracy",
     0x2A13: "Time Source",
     0x2A14: "Reference Time Information",
-    # 0x2a15 undefined */
+    0x2A15: "Time Broadcast",
     0x2A16: "Time Update Control Point",
     0x2A17: "Time Update State",
     0x2A18: "Glucose Measurement",
@@ -209,7 +363,9 @@ uuid16_dict = {
     0x2A2A: "IEEE 11073-20601 Regulatory Cert. Data List",
     0x2A2B: "Current Time",
     0x2A2C: "Magnetic Declination",
-    # 0x2a2d to 0x2a30 undefined */
+    # 0x2a2d to 0x2a2e undefined */
+    0x2A2F: "Position 2D",
+    0x2A30: "Position 3D",
     0x2A31: "Scan Refresh",
     0x2A32: "Boot Keyboard Output Report",
     0x2A33: "Boot Mouse Input Report",
@@ -219,7 +375,11 @@ uuid16_dict = {
     0x2A37: "Heart Rate Measurement",
     0x2A38: "Body Sensor Location",
     0x2A39: "Heart Rate Control Point",
-    # 0x2a3a to 0x2a3e undefined */
+    0x2A3A: "Removable",
+    0x2A3B: "Service Required",
+    0x2A3C: "Scientific Temperature Celsius",
+    0x2A3D: "String",
+    0x2A3E: "Network Availability",
     0x2A3F: "Alert Status",
     0x2A40: "Ringer Control Point",
     0x2A41: "Ringer Setting",
@@ -244,14 +404,17 @@ uuid16_dict = {
     0x2A54: "RSC Feature",
     0x2A55: "SC Control Point",
     0x2A56: "Digital",
-    # 0x2a57 undefined */
+    0x2A57: "Digital Output",
     0x2A58: "Analog",
-    # 0x2a59 undefined */
+    0x2A59: "Analog Output",
     0x2A5A: "Aggregate",
     0x2A5B: "CSC Measurement",
     0x2A5C: "CSC Feature",
     0x2A5D: "Sensor Location",
-    # 0x2a5e to 0x2a62 undefined */
+    0x2A5E: "PLX Spot-Check Measurement",
+    0x2A5F: "PLX Continuous Measurement Characteristic",
+    0x2A60: "PLX Features",
+    0x2A62: "Pulse Oximetry Control Point",
     0x2A63: "Cycling Power Measurement",
     0x2A64: "Cycling Power Vector",
     0x2A65: "Cycling Power Feature",
@@ -375,275 +538,10 @@ uuid16_dict = {
     0x2ADC: "Mesh Provisioning Data Out",
     0x2ADD: "Mesh Proxy Data In",
     0x2ADE: "Mesh Proxy Data Out",
-    0x2A59: "Analog Output",
-    0x2B29: "Client Supported Features",
-    0x2B2A: "Database Hash",
-    0x2AED: "Date UTC",
-    0x2A57: "Digital Output",
-    0x2B22: "IDD Annunciation Status",
-    0x2B25: "IDD Command Control Point",
-    0x2B26: "IDD Command Data",
-    0x2B23: "IDD Features",
-    0x2B28: "IDD History Data",
-    0x2B27: "IDD Record Access Control Point",
-    0x2B21: "IDD Status",
-    0x2B20: "IDD Status Changed",
-    0x2B24: "IDD Status Reader Control Point",
-    0x2A3E: "Network Availability",
-    0x2A5F: "PLX Continuous Measurement Characteristic",
-    0x2A60: "PLX Features",
-    0x2A5E: "PLX Spot-Check Measurement",
-    0x2A2F: "Position 2D",
-    0x2A30: "Position 3D",
-    0x2A62: "Pulse Oximetry Control Point",
-    0x2B1D: "RC Feature",
-    0x2B1E: "RC Settings",
-    0x2B1F: "Reconnection Configuration Control Point",
-    0x2A3A: "Removable",
-    0x2A3C: "Scientific Temperature Celsius",
-    0x2A10: "Secondary Time Zone",
-    0x2A3B: "Service Required",
-    0x2A3D: "String",
-    0x2A15: "Time Broadcast",
-    # vendor defined */
-    0xFEFF: "GN Netcom",
-    0xFEFE: "GN ReSound A/S",
-    0xFEFD: "Gimbal: Inc.",
-    0xFEFC: "Gimbal: Inc.",
-    0xFEFB: "Stollmann E+V GmbH",
-    0xFEFA: "PayPal: Inc.",
-    0xFEF9: "PayPal: Inc.",
-    0xFEF8: "Aplix Corporation",
-    0xFEF7: "Aplix Corporation",
-    0xFEF6: "Wicentric: Inc.",
-    0xFEF5: "Dialog Semiconductor GmbH",
-    0xFEF4: "Google",
-    0xFEF3: "Google",
-    0xFEF2: "CSR",
-    0xFEF1: "CSR",
-    0xFEF0: "Intel",
-    0xFEEF: "Polar Electro Oy",
-    0xFEEE: "Polar Electro Oy",
-    0xFEED: "Tile: Inc.",
-    0xFEEC: "Tile: Inc.",
-    0xFEEB: "Swirl Networks: Inc.",
-    0xFEEA: "Swirl Networks: Inc.",
-    0xFEE9: "Quintic Corp.",
-    0xFEE8: "Quintic Corp.",
-    0xFEE7: "Tencent Holdings Limited",
-    0xFEE6: "Seed Labs: Inc.",
-    0xFEE5: "Nordic Semiconductor ASA",
-    0xFEE4: "Nordic Semiconductor ASA",
-    0xFEE3: "Anki: Inc.",
-    0xFEE2: "Anki: Inc.",
-    0xFEE1: "Anhui Huami Information Technology Co.",
-    0xFEE0: "Anhui Huami Information Technology Co.",
-    0xFEDF: "Design SHIFT",
-    0xFEDE: "Coin: Inc.",
-    0xFEDD: "Jawbone",
-    0xFEDC: "Jawbone",
-    0xFEDB: "Perka: Inc.",
-    0xFEDA: "ISSC Technologies Corporation",
-    0xFED9: "Pebble Technology Corporation",
-    0xFED8: "Google",
-    0xFED7: "Broadcom Corporation",
-    0xFED6: "Broadcom Corporation",
-    0xFED5: "Plantronics Inc.",
-    0xFED4: "Apple: Inc.",
-    0xFED3: "Apple: Inc.",
-    0xFED2: "Apple: Inc.",
-    0xFED1: "Apple: Inc.",
-    0xFED0: "Apple: Inc.",
-    0xFECF: "Apple: Inc.",
-    0xFECE: "Apple: Inc.",
-    0xFECD: "Apple: Inc.",
-    0xFECC: "Apple: Inc.",
-    0xFECB: "Apple: Inc.",
-    0xFECA: "Apple: Inc.",
-    0xFEC9: "Apple: Inc.",
-    0xFEC8: "Apple: Inc.",
-    0xFEC7: "Apple: Inc.",
-    0xFEC6: "Kocomojo: LLC",
-    0xFEC5: "Realtek Semiconductor Corp.",
-    0xFEC4: "PLUS Location Systems",
-    0xFEC3: "360fly: Inc.",
-    0xFEC2: "Blue Spark Technologies: Inc.",
-    0xFEC1: "KDDI Corporation",
-    0xFEC0: "KDDI Corporation",
-    0xFEBF: "Nod: Inc.",
-    0xFEBE: "Bose Corporation",
-    0xFEBD: "Clover Network: Inc.",
-    0xFEBC: "Dexcom: Inc.",
-    0xFEBB: "adafruit industries",
-    0xFEBA: "Tencent Holdings Limited",
-    0xFEB9: "LG Electronics",
-    0xFEB8: "Facebook: Inc.",
-    0xFEB7: "Facebook: Inc.",
-    0xFEB6: "Vencer Co: Ltd",
-    0xFEB5: "WiSilica Inc.",
-    0xFEB4: "WiSilica Inc.",
-    0xFEB3: "Taobao",
-    0xFEB2: "Microsoft Corporation",
-    0xFEB1: "Electronics Tomorrow Limited",
-    0xFEB0: "Nest Labs Inc.",
-    0xFEAF: "Nest Labs Inc.",
-    0xFEAE: "Nokia Corporation",
-    0xFEAD: "Nokia Corporation",
-    0xFEAC: "Nokia Corporation",
-    0xFEAB: "Nokia Corporation",
-    0xFEAA: "Google",
-    0xFEA9: "Savant Systems LLC",
-    0xFEA8: "Savant Systems LLC",
-    0xFEA7: "UTC Fire and Security",
-    0xFEA6: "GoPro: Inc.",
-    0xFEA5: "GoPro: Inc.",
-    0xFEA4: "Paxton Access Ltd",
-    0xFEA3: "ITT Industries",
-    0xFEA2: "Intrepid Control Systems: Inc.",
-    0xFEA1: "Intrepid Control Systems: Inc.",
-    0xFEA0: "Google",
-    0xFE9F: "Google",
-    0xFE9E: "Dialog Semiconductor B.V.",
-    0xFE9D: "Mobiquity Networks Inc",
-    0xFE9C: "GSI Laboratories: Inc.",
-    0xFE9B: "Samsara Networks: Inc",
-    0xFE9A: "Estimote",
-    0xFE99: "Currant: Inc.",
-    0xFE98: "Currant: Inc.",
-    0xFE97: "Tesla Motor Inc.",
-    0xFE96: "Tesla Motor Inc.",
-    0xFE95: "Xiaomi Inc.",
-    0xFE94: "OttoQ Inc.",
-    0xFE93: "OttoQ Inc.",
-    0xFE92: "Jarden Safety & Security",
-    0xFE91: "Shanghai Imilab Technology Co.,Ltd",
-    0xFE90: "JUMA",
-    0xFE8F: "CSR",
-    0xFE8E: "ARM Ltd",
-    0xFE8D: "Interaxon Inc.",
-    0xFE8C: "TRON Forum",
-    0xFE8B: "Apple: Inc.",
-    0xFE8A: "Apple: Inc.",
-    0xFE89: "B&O Play A/S",
-    0xFE88: "SALTO SYSTEMS S.L.",
-    0xFE87: "Qingdao Yeelink Information Technology Co.: Ltd. ( 青岛亿联客信息技术有限公司 )",
-    0xFE86: "HUAWEI Technologies Co.: Ltd. ( 华为技术有限公司 )",
-    0xFE85: "RF Digital Corp",
-    0xFE84: "RF Digital Corp",
-    0xFE83: "Blue Bite",
-    0xFE82: "Medtronic Inc.",
-    0xFE81: "Medtronic Inc.",
-    0xFE80: "Doppler Lab",
-    0xFE7F: "Doppler Lab",
-    0xFE7E: "Awear Solutions Ltd",
-    0xFE7D: "Aterica Health Inc.",
-    0xFE7C: "Stollmann E+V GmbH",
-    0xFE7B: "Orion Labs: Inc.",
-    0xFE7A: "Bragi GmbH",
-    0xFE79: "Zebra Technologies",
-    0xFE78: "Hewlett-Packard Company",
-    0xFE77: "Hewlett-Packard Company",
-    0xFE76: "TangoMe",
-    0xFE75: "TangoMe",
-    0xFE74: "unwire",
-    0xFE73: "St. Jude Medical: Inc.",
-    0xFE72: "St. Jude Medical: Inc.",
-    0xFE71: "Plume Design Inc",
-    0xFE70: "Beijing Jingdong Century Trading Co.: Ltd.",
-    0xFE6F: "LINE Corporation",
-    0xFE6E: "The University of Tokyo",
-    0xFE6D: "The University of Tokyo",
-    0xFE6C: "TASER International: Inc.",
-    0xFE6B: "TASER International: Inc.",
-    0xFE6A: "Kontakt Micro-Location Sp. z o.o.",
-    0xFE69: "Qualcomm Life Inc",
-    0xFE68: "Qualcomm Life Inc",
-    0xFE67: "Lab Sensor Solutions",
-    0xFE66: "Intel Corporation",
-    0xFE65: "CHIPOLO d.o.o.",
-    0xFE64: "Siemens AG",
-    0xFE63: "Connected Yard: Inc.",
-    0xFE62: "Indagem Tech LLC",
-    0xFE61: "Logitech International SA",
-    0xFE60: "Lierda Science & Technology Group Co.: Ltd.",
-    0xFE5F: "Eyefi: Inc.",
-    0xFE5E: "Plastc Corporation",
-    0xFE5D: "Grundfos A/S",
-    0xFE5C: "million hunters GmbH",
-    0xFE5B: "GT-tronics HK Ltd",
-    0xFE5A: "Chronologics Corporation",
-    0xFE59: "Nordic Semiconductor ASA",
-    0xFE58: "Nordic Semiconductor ASA",
-    0xFE57: "Dotted Labs",
-    0xFE56: "Google Inc.",
-    0xFE55: "Google Inc.",
-    0xFE54: "Motiv: Inc.",
-    0xFE53: "3M",
-    0xFE52: "SetPoint Medical",
-    0xFE51: "SRAM",
-    0xFE50: "Google Inc.",
-    0xFE4F: "Molekule: Inc.",
-    0xFE4E: "NTT docomo",
-    0xFE4D: "Casambi Technologies Oy",
-    0xFE4C: "Volkswagen AG",
-    0xFE4B: "Koninklijke Philips N.V.",
-    0xFE4A: "OMRON HEALTHCARE Co.: Ltd.",
-    0xFE49: "SenionLab AB",
-    0xFE48: "General Motors",
-    0xFE47: "General Motors",
-    0xFE46: "B&O Play A/S",
-    0xFE45: "Snapchat Inc",
-    0xFE44: "SK Telecom",
-    0xFE43: "Andreas Stihl AG & Co. KG",
-    0xFE42: "Nets A/S",
-    0xFE41: "Inugo Systems Limited",
-    0xFE40: "Inugo Systems Limited",
-    0xFE3F: "Friday Labs Limited",
-    0xFE3E: "BD Medical",
-    0xFE3D: "BD Medical",
-    0xFE3C: "Alibaba",
-    0xFE3B: "Dolby Laboratories",
-    0xFE3A: "TTS Tooltechnic Systems AG & Co. KG",
-    0xFE39: "TTS Tooltechnic Systems AG & Co. KG",
-    0xFE38: "Spaceek LTD",
-    0xFE37: "Spaceek LTD",
-    0xFE36: "HUAWEI Technologies Co.: Ltd",
-    0xFE35: "HUAWEI Technologies Co.: Ltd",
-    0xFE34: "SmallLoop LLC",
-    0xFE33: "CHIPOLO d.o.o.",
-    0xFE32: "Pro-Mark: Inc.",
-    0xFE31: "Volkswagen AG",
-    0xFE30: "Volkswagen AG",
-    0xFE2F: "CRESCO Wireless: Inc",
-    0xFE2E: "ERi,Inc.",
-    0xFE2D: "SMART INNOVATION Co.,Ltd",
-    0xFE2C: "Google Inc.",
-    0xFE2B: "ITT Industries",
-    0xFE2A: "DaisyWorks: Inc.",
-    0xFE29: "Gibson Innovations",
-    0xFE28: "Ayla Network",
-    0xFE27: "Google Inc.",
-    0xFE26: "Google Inc.",
-    0xFE25: "Apple: Inc.",
-    0xFE24: "August Home Inc",
-    0xFE23: "Zoll Medical Corporation",
-    0xFE22: "Zoll Medical Corporation",
-    0xFE21: "Bose Corporation",
-    0xFE20: "Emerson",
-    0xFE1F: "Garmin International: Inc.",
-    0xFE1E: "Smart Innovations Co.: Ltd",
-    0xFE1D: "Illuminati Instrument Corporation",
-    0xFE1C: "NetMedia: Inc.",
-    # SDO defined */
-    0xFFFC: "AirFuel Alliance",
-    0xFFFE: "Alliance for Wireless Power (A4WP)",
-    0xFFFD: "Fast IDentity Online Alliance (FIDO)",
-    # Mesh Characteristics
     0x2AE0: "Average Current",
     0x2AE1: "Average Voltage",
     0x2AE2: "Boolean",
     0x2AE3: "Chromatic Distance From Planckian",
-    0x2B1C: "Chromaticity Coordinate",
     0x2AE4: "Chromaticity Coordinates",
     0x2AE5: "Chromaticity In CCT And Duv Values",
     0x2AE6: "Chromaticity Tolerance",
@@ -675,20 +573,16 @@ uuid16_dict = {
     0x2B00: "Luminous Flux Range",
     0x2B01: "Luminous Intensity",
     0x2B02: "Mass Flow",
-    0x2ADB: "Mesh Provisioning Data In",
-    0x2ADC: "Mesh Provisioning Data Out",
-    0x2ADD: "Mesh Proxy Data In",
-    0x2ADE: "Mesh Proxy Data Out",
     0x2B03: "Perceived Lightness",
     0x2B04: "Percentage 8",
     0x2B05: "Power",
     0x2B06: "Power Specification",
     0x2B07: "Relative Runtime In A Current Range",
     0x2B08: "Relative Runtime In A Generic Level Range",
-    0x2B0B: "Relative Value In A Period of Day",
-    0x2B0C: "Relative Value In A Temperature Range",
     0x2B09: "Relative Value In A Voltage Range",
     0x2B0A: "Relative Value In An Illuminance Range",
+    0x2B0B: "Relative Value In A Period of Day",
+    0x2B0C: "Relative Value In A Temperature Range",
     0x2B0D: "Temperature 8",
     0x2B0E: "Temperature 8 In A Period Of Day",
     0x2B0F: "Temperature 8 Statistics",
@@ -704,6 +598,377 @@ uuid16_dict = {
     0x2B19: "Voltage Specification",
     0x2B1A: "Voltage Statistics",
     0x2B1B: "Volume Flow",
+    0x2B1C: "Chromaticity Coordinate",
+    0x2B1D: "RC Feature",
+    0x2B1E: "RC Settings",
+    0x2B1F: "Reconnection Configuration Control Point",
+    0x2B20: "IDD Status Changed",
+    0x2B21: "IDD Status",
+    0x2B22: "IDD Annunciation Status",
+    0x2B23: "IDD Features",
+    0x2B24: "IDD Status Reader Control Point",
+    0x2B25: "IDD Command Control Point",
+    0x2B26: "IDD Command Data",
+    0x2B27: "IDD Record Access Control Point",
+    0x2B28: "IDD History Data",
+    0x2B29: "Client Supported Features",
+    0x2B2A: "Database Hash",
+    0x2B2B: "BSS Control Point",
+    0x2B2C: "BSS Response",
+    0x2B2D: "Emergency ID",
+    0x2B2E: "Emergency Text",
+    0x2B34: "Enhanced Blood Pressure Measurement",
+    0x2B35: "Enhanced Intermediate Cuff Pressure",
+    0x2B36: "Blood Pressure Record",
+    # 0x2B37 undefined
+    0x2B38: "BR-EDR Handover Data",
+    0x2B39: "Bluetooth SIG Data",
+    0x2B3A: "Server Supported Features",
+    0x2B3B: "Physical Activity Monitor Features",
+    0x2B3C: "General Activity Instantaneous Data",
+    0x2B3D: "General Activity Summary Data",
+    0x2B3E: "CardioRespiratory Activity Instantaneous Data",
+    0x2B3F: "CardioRespiratory Activity Summary Data",
+    0x2B40: "Step Counter Activity Summary Data",
+    0x2B41: "Sleep Activity Instantaneous Data",
+    0x2B42: "Sleep Activity Summary Data",
+    0x2B43: "Physical Activity Monitor Control Point",
+    0x2B44: "Current Session",
+    0x2B45: "Session",
+    0x2B46: "Preferred Units",
+    0x2B47: "High Resolution Height",
+    0x2B48: "Middle Name",
+    0x2B49: "Stride Length",
+    0x2B4A: "Handedness",
+    0x2B4B: "Device Wearing Position",
+    0x2B4C: "Four Zone Heart Rate Limits",
+    0x2B4D: "High Intensity Exercise Threshold",
+    0x2B4E: "Activity Goal",
+    0x2B4F: "Sedentary Interval Notification",
+    0x2B50: "Caloric Intake",
+    0x2B77: "Audio Input State",
+    0x2B78: "Gain Settings Attribute",
+    0x2B79: "Audio Input Type",
+    0x2B7A: "Audio Input Status",
+    0x2B7B: "Audio Input Control Point",
+    0x2B7C: "Audio Input Description",
+    0x2B7D: "Volume State",
+    0x2B7E: "Volume Control Point",
+    0x2B7F: "Volume Flags",
+    0x2B80: "Offset State",
+    0x2B81: "Audio Location",
+    0x2B82: "Volume Offset Control Point",
+    0x2B83: "Audio Output Description",
+    0x2B84: "Set Identity Resolving Key Characteristic",
+    0x2B85: "Size Characteristic",
+    0x2B86: "Lock Characteristic",
+    0x2B87: "Rank Characteristic",
+    0x2B8E: "Device Time Feature",
+    0x2B8F: "Device Time Parameters",
+    0x2B90: "Device Time",
+    0x2B91: "Device Time Control Point",
+    0x2B92: "Time Change Log Data",
+    0x2B93: "Media Player Name",
+    0x2B94: "Media Player Icon Object ID",
+    0x2B95: "Media Player Icon URL",
+    0x2B96: "Track Changed",
+    0x2B97: "Track Title",
+    0x2B98: "Track Duration",
+    0x2B99: "Track Position",
+    0x2B9A: "Playback Speed",
+    0x2B9B: "Seeking Speed",
+    0x2B9C: "Current Track Segments Object ID",
+    0x2B9D: "Current Track Object ID",
+    0x2B9E: "Next Track Object ID",
+    0x2B9F: "Parent Group Object ID",
+    0x2BA0: "Current Group Object ID",
+    0x2BA1: "Playing Order",
+    0x2BA2: "Playing Orders Supported",
+    0x2BA3: "Media State",
+    0x2BA4: "Media Control Point",
+    0x2BA5: "Media Control Point Opcodes Supported",
+    0x2BA6: "Search Results Object ID",
+    0x2BA7: "Search Control Point",
+    0x2BA9: "Media Player Icon Object Type",
+    0x2BAA: "Track Segments Object Type",
+    0x2BAB: "Track Object Type",
+    0x2BAC: "Group Object Type",
+    0x2BAD: "Constant Tone Extension Enable",
+    0x2BAE: "Advertising Constant Tone Extension Minimum Length",
+    0x2BAF: "Advertising Constant Tone Extension Minimum Transmit Count",
+    0x2BB0: "Advertising Constant Tone Extension Transmit Duration",
+    0x2BB1: "Advertising Constant Tone Extension Interval",
+    0x2BB2: "Advertising Constant Tone Extension PHY",
+    0x2BB3: "Bearer Provider Name",
+    0x2BB4: "Bearer UCI",
+    0x2BB5: "Bearer Technology",
+    0x2BB6: "Bearer URI Schemes Supported List",
+    0x2BB7: "Bearer Signal Strength",
+    0x2BB8: "Bearer Signal Strength Reporting Interval",
+    0x2BB9: "Bearer List Current Calls",
+    0x2BBA: "Content Control ID",
+    0x2BBB: "Status Flags",
+    0x2BBC: "Incoming Call Target Bearer URI",
+    0x2BBD: "Call State",
+    0x2BBE: "Call Control Point",
+    0x2BBF: "Call Control Point Optional Opcodes",
+    0x2BC0: "Termination Reason",
+    0x2BC1: "Incoming Call",
+    0x2BC2: "Call Friendly Name",
+    0x2BC3: "Mute",
+    0x2BC4: "Sink ASE",
+    0x2BC5: "Source ASE",
+    0x2BC6: "ASE Control Point",
+    0x2BC7: "Broadcast Audio Scan Control Point",
+    0x2BC8: "Broadcast Receive State",
+    0x2BC9: "Sink PAC",
+    0x2BCA: "Sink Audio Locations",
+    0x2BCB: "Source PAC",
+    0x2BCC: "Source Audio Locations",
+    0x2BCD: "Available Audio Contexts",
+    0x2BCE: "Supported Audio Contexts",
+    0x2BCF: "Ammonia Concentration",
+    0x2BD0: "Carbon Monoxide Concentration",
+    0x2BD1: "Methane Concentration",
+    0x2BD2: "Nitrogen Dioxide Concentration",
+    0x2BD3: "Non-Methane Volatile Organic Compounds Concentration",
+    0x2BD4: "Ozone Concentration",
+    0x2BD5: "Particulate Matter - PM1 Concentration",
+    0x2BD6: "Particulate Matter - PM2.5 Concentration",
+    0x2BD7: "Particulate Matter - PM10 Concentration",
+    0x2BD8: "Sulfur Dioxide Concentration",
+    0x2BD9: "Sulfur Hexafluoride Concentration",
+    0xFE1C: "NetMedia: Inc.",
+    0xFE1D: "Illuminati Instrument Corporation",
+    0xFE1E: "Smart Innovations Co.: Ltd",
+    0xFE1F: "Garmin International: Inc.",
+    0xFE20: "Emerson",
+    0xFE21: "Bose Corporation",
+    0xFE22: "Zoll Medical Corporation",
+    0xFE23: "Zoll Medical Corporation",
+    0xFE24: "August Home Inc",
+    0xFE25: "Apple: Inc.",
+    0xFE26: "Google Inc.",
+    0xFE27: "Google Inc.",
+    0xFE28: "Ayla Network",
+    0xFE29: "Gibson Innovations",
+    0xFE2A: "DaisyWorks: Inc.",
+    0xFE2B: "ITT Industries",
+    0xFE2C: "Google Inc.",
+    0xFE2D: "SMART INNOVATION Co.,Ltd",
+    0xFE2E: "ERi,Inc.",
+    0xFE2F: "CRESCO Wireless: Inc",
+    0xFE30: "Volkswagen AG",
+    0xFE31: "Volkswagen AG",
+    0xFE32: "Pro-Mark: Inc.",
+    0xFE33: "CHIPOLO d.o.o.",
+    0xFE34: "SmallLoop LLC",
+    0xFE35: "HUAWEI Technologies Co.: Ltd",
+    0xFE36: "HUAWEI Technologies Co.: Ltd",
+    0xFE37: "Spaceek LTD",
+    0xFE38: "Spaceek LTD",
+    0xFE39: "TTS Tooltechnic Systems AG & Co. KG",
+    0xFE3A: "TTS Tooltechnic Systems AG & Co. KG",
+    0xFE3B: "Dolby Laboratories",
+    0xFE3C: "Alibaba",
+    0xFE3D: "BD Medical",
+    0xFE3E: "BD Medical",
+    0xFE3F: "Friday Labs Limited",
+    0xFE40: "Inugo Systems Limited",
+    0xFE41: "Inugo Systems Limited",
+    0xFE42: "Nets A/S",
+    0xFE43: "Andreas Stihl AG & Co. KG",
+    0xFE44: "SK Telecom",
+    0xFE45: "Snapchat Inc",
+    0xFE46: "B&O Play A/S",
+    0xFE47: "General Motors",
+    0xFE48: "General Motors",
+    0xFE49: "SenionLab AB",
+    0xFE4A: "OMRON HEALTHCARE Co.: Ltd.",
+    0xFE4B: "Koninklijke Philips N.V.",
+    0xFE4C: "Volkswagen AG",
+    0xFE4D: "Casambi Technologies Oy",
+    0xFE4E: "NTT docomo",
+    0xFE4F: "Molekule: Inc.",
+    0xFE50: "Google Inc.",
+    0xFE51: "SRAM",
+    0xFE52: "SetPoint Medical",
+    0xFE53: "3M",
+    0xFE54: "Motiv: Inc.",
+    0xFE55: "Google Inc.",
+    0xFE56: "Google Inc.",
+    0xFE57: "Dotted Labs",
+    0xFE58: "Nordic Semiconductor ASA",
+    0xFE59: "Nordic Semiconductor ASA",
+    0xFE5A: "Chronologics Corporation",
+    0xFE5B: "GT-tronics HK Ltd",
+    0xFE5C: "million hunters GmbH",
+    0xFE5D: "Grundfos A/S",
+    0xFE5E: "Plastc Corporation",
+    0xFE5F: "Eyefi: Inc.",
+    0xFE60: "Lierda Science & Technology Group Co.: Ltd.",
+    0xFE61: "Logitech International SA",
+    0xFE62: "Indagem Tech LLC",
+    0xFE63: "Connected Yard: Inc.",
+    0xFE64: "Siemens AG",
+    0xFE65: "CHIPOLO d.o.o.",
+    0xFE66: "Intel Corporation",
+    0xFE67: "Lab Sensor Solutions",
+    0xFE68: "Qualcomm Life Inc",
+    0xFE69: "Qualcomm Life Inc",
+    0xFE6A: "Kontakt Micro-Location Sp. z o.o.",
+    0xFE6B: "TASER International: Inc.",
+    0xFE6C: "TASER International: Inc.",
+    0xFE6D: "The University of Tokyo",
+    0xFE6E: "The University of Tokyo",
+    0xFE6F: "LINE Corporation",
+    0xFE70: "Beijing Jingdong Century Trading Co.: Ltd.",
+    0xFE71: "Plume Design Inc",
+    0xFE72: "St. Jude Medical: Inc.",
+    0xFE73: "St. Jude Medical: Inc.",
+    0xFE74: "unwire",
+    0xFE75: "TangoMe",
+    0xFE76: "TangoMe",
+    0xFE77: "Hewlett-Packard Company",
+    0xFE78: "Hewlett-Packard Company",
+    0xFE79: "Zebra Technologies",
+    0xFE7A: "Bragi GmbH",
+    0xFE7B: "Orion Labs: Inc.",
+    0xFE7C: "Stollmann E+V GmbH",
+    0xFE7D: "Aterica Health Inc.",
+    0xFE7E: "Awear Solutions Ltd",
+    0xFE7F: "Doppler Lab",
+    0xFE80: "Doppler Lab",
+    0xFE81: "Medtronic Inc.",
+    0xFE82: "Medtronic Inc.",
+    0xFE83: "Blue Bite",
+    0xFE84: "RF Digital Corp",
+    0xFE85: "RF Digital Corp",
+    0xFE86: "HUAWEI Technologies Co.: Ltd.",
+    0xFE87: "Qingdao Yeelink Information Technology Co.: Ltd.",
+    0xFE88: "SALTO SYSTEMS S.L.",
+    0xFE89: "B&O Play A/S",
+    0xFE8A: "Apple: Inc.",
+    0xFE8B: "Apple: Inc.",
+    0xFE8C: "TRON Forum",
+    0xFE8D: "Interaxon Inc.",
+    0xFE8E: "ARM Ltd",
+    0xFE8F: "CSR",
+    0xFE90: "JUMA",
+    0xFE91: "Shanghai Imilab Technology Co.,Ltd",
+    0xFE92: "Jarden Safety & Security",
+    0xFE93: "OttoQ Inc.",
+    0xFE94: "OttoQ Inc.",
+    0xFE95: "Xiaomi Inc.",
+    0xFE96: "Tesla Motor Inc.",
+    0xFE97: "Tesla Motor Inc.",
+    0xFE98: "Currant: Inc.",
+    0xFE99: "Currant: Inc.",
+    0xFE9A: "Estimote",
+    0xFE9B: "Samsara Networks: Inc",
+    0xFE9C: "GSI Laboratories: Inc.",
+    0xFE9D: "Mobiquity Networks Inc",
+    0xFE9E: "Dialog Semiconductor B.V.",
+    0xFE9F: "Google",
+    0xFEA0: "Google",
+    0xFEA1: "Intrepid Control Systems: Inc.",
+    0xFEA2: "Intrepid Control Systems: Inc.",
+    0xFEA3: "ITT Industries",
+    0xFEA4: "Paxton Access Ltd",
+    0xFEA5: "GoPro: Inc.",
+    0xFEA6: "GoPro: Inc.",
+    0xFEA7: "UTC Fire and Security",
+    0xFEA8: "Savant Systems LLC",
+    0xFEA9: "Savant Systems LLC",
+    0xFEAA: "Google",
+    0xFEAB: "Nokia Corporation",
+    0xFEAC: "Nokia Corporation",
+    0xFEAD: "Nokia Corporation",
+    0xFEAE: "Nokia Corporation",
+    0xFEAF: "Nest Labs Inc.",
+    0xFEB0: "Nest Labs Inc.",
+    0xFEB1: "Electronics Tomorrow Limited",
+    0xFEB2: "Microsoft Corporation",
+    0xFEB3: "Taobao",
+    0xFEB4: "WiSilica Inc.",
+    0xFEB5: "WiSilica Inc.",
+    0xFEB6: "Vencer Co: Ltd",
+    0xFEB7: "Facebook: Inc.",
+    0xFEB8: "Facebook: Inc.",
+    0xFEB9: "LG Electronics",
+    0xFEBA: "Tencent Holdings Limited",
+    0xFEBB: "adafruit industries",
+    0xFEBC: "Dexcom: Inc.",
+    0xFEBD: "Clover Network: Inc.",
+    0xFEBE: "Bose Corporation",
+    0xFEBF: "Nod: Inc.",
+    0xFEC0: "KDDI Corporation",
+    0xFEC1: "KDDI Corporation",
+    0xFEC2: "Blue Spark Technologies: Inc.",
+    0xFEC3: "360fly: Inc.",
+    0xFEC4: "PLUS Location Systems",
+    0xFEC5: "Realtek Semiconductor Corp.",
+    0xFEC6: "Kocomojo: LLC",
+    0xFEC7: "Apple: Inc.",
+    0xFEC8: "Apple: Inc.",
+    0xFEC9: "Apple: Inc.",
+    0xFECA: "Apple: Inc.",
+    0xFECB: "Apple: Inc.",
+    0xFECC: "Apple: Inc.",
+    0xFECD: "Apple: Inc.",
+    0xFECE: "Apple: Inc.",
+    0xFECF: "Apple: Inc.",
+    0xFED0: "Apple: Inc.",
+    0xFED1: "Apple: Inc.",
+    0xFED2: "Apple: Inc.",
+    0xFED3: "Apple: Inc.",
+    0xFED4: "Apple: Inc.",
+    0xFED5: "Plantronics Inc.",
+    0xFED6: "Broadcom Corporation",
+    0xFED7: "Broadcom Corporation",
+    0xFED8: "Google",
+    0xFED9: "Pebble Technology Corporation",
+    0xFEDA: "ISSC Technologies Corporation",
+    0xFEDB: "Perka: Inc.",
+    0xFEDC: "Jawbone",
+    0xFEDD: "Jawbone",
+    0xFEDE: "Coin: Inc.",
+    0xFEDF: "Design SHIFT",
+    0xFEE0: "Anhui Huami Information Technology Co.",
+    0xFEE1: "Anhui Huami Information Technology Co.",
+    0xFEE2: "Anki: Inc.",
+    0xFEE3: "Anki: Inc.",
+    0xFEE4: "Nordic Semiconductor ASA",
+    0xFEE5: "Nordic Semiconductor ASA",
+    0xFEE6: "Seed Labs: Inc.",
+    0xFEE7: "Tencent Holdings Limited",
+    0xFEE8: "Quintic Corp.",
+    0xFEE9: "Quintic Corp.",
+    0xFEEA: "Swirl Networks: Inc.",
+    0xFEEB: "Swirl Networks: Inc.",
+    0xFEEC: "Tile: Inc.",
+    0xFEED: "Tile: Inc.",
+    0xFEEE: "Polar Electro Oy",
+    0xFEEF: "Polar Electro Oy",
+    0xFEF0: "Intel",
+    0xFEF1: "CSR",
+    0xFEF2: "CSR",
+    0xFEF3: "Google",
+    0xFEF4: "Google",
+    0xFEF5: "Dialog Semiconductor GmbH",
+    0xFEF6: "Wicentric: Inc.",
+    0xFEF7: "Aplix Corporation",
+    0xFEF8: "Aplix Corporation",
+    0xFEF9: "PayPal: Inc.",
+    0xFEFA: "PayPal: Inc.",
+    0xFEFB: "Stollmann E+V GmbH",
+    0xFEFC: "Gimbal: Inc.",
+    0xFEFD: "Gimbal: Inc.",
+    0xFEFE: "GN ReSound A/S",
+    0xFEFF: "GN Netcom",
+    0xFFFC: "AirFuel Alliance",
+    0xFFFD: "Fast IDentity Online Alliance (FIDO)",
+    0xFFFE: "Alliance for Wireless Power (A4WP)",
 }
 
 uuid128_dict = {
@@ -883,3 +1148,20 @@ def register_uuids(uuids_to_descriptions: Dict[str, str]) -> None:
 
     """
     uuid128_dict.update(uuids_to_descriptions)
+
+
+def normalize_uuid_str(uuid: str) -> str:
+    """
+    Normaizes a UUID to the format used by Bleak.
+
+    - Converted to lower case.
+    - 16-bit UUIDs are expanded to 128-bit.
+
+    .. versionadded:: 0.20.0
+    """
+    if len(uuid) == 4:
+        # Bluetooth SIG registered 16-bit UUIDs
+        uuid = f"0000{uuid}-0000-1000-8000-00805f9b34fb"
+
+    # let UUID class do the validation and conversion to lower case
+    return str(UUID(uuid))
